@@ -14,8 +14,6 @@
   #define FILE_BAD_HANDLE NULL
 #endif
 
-class RAROptions;
-
 enum FILE_HANDLETYPE {FILE_HANDLENORMAL,FILE_HANDLESTD};
 
 enum FILE_ERRORTYPE {FILE_SUCCESS,FILE_NOTFOUND,FILE_READERROR};
@@ -43,7 +41,7 @@ enum FILE_MODE_FLAGS {
   FMF_STANDARDNAMES=32,
 
   // Mode flags are not defined yet.
-  FMF_UNDEFINED=256
+  // FMF_UNDEFINED=256
 };
 
 enum FILE_READ_ERROR_MODE {
@@ -59,14 +57,23 @@ class File
     FileHandle hFile;
     bool LastWrite;
     FILE_HANDLETYPE HandleType;
+    
+    // If we read the user input in console prompts from stdin, we shall
+    // process the available line immediately, not waiting for rest of data.
+    // Otherwise apps piping user responses to multiple Ask() prompts can
+    // hang if no more data is available yet and pipe isn't closed.
+    // If we read RAR archive or other file data from stdin, we shall collect
+    // the entire requested block as long as pipe isn't closed, so we get
+    // complete archive headers, not split between different reads.
+    bool LineInput;
+
     bool SkipClose;
     FILE_READ_ERROR_MODE ReadErrorMode;
     bool NewFile;
     bool AllowDelete;
     bool AllowExceptions;
 #ifdef _WIN_ALL
-    bool NoSequentialRead;
-    uint CreateMode;
+    // uint CreateMode;
 #endif
     bool PreserveAtime;
     bool TruncatedAfterReadError;
@@ -75,7 +82,7 @@ class File
   protected:
     bool OpenShared; // Set by 'Archive' class.
   public:
-    wchar FileName[NM];
+    std::wstring FileName;
 
     FILE_ERRORTYPE ErrorType;
   public:
@@ -85,15 +92,15 @@ class File
 
     // Several functions below are 'virtual', because they are redefined
     // by Archive for QOpen and by MultiFile for split files in WinRAR.
-    virtual bool Open(const wchar *Name,uint Mode=FMF_READ);
-    void TOpen(const wchar *Name);
-    bool WOpen(const wchar *Name);
-    bool Create(const wchar *Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
-    void TCreate(const wchar *Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
-    bool WCreate(const wchar *Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
+    virtual bool Open(const std::wstring &Name,uint Mode=FMF_READ);
+    void TOpen(const std::wstring &Name);
+    bool WOpen(const std::wstring &Name);
+    bool Create(const std::wstring &Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
+    void TCreate(const std::wstring &Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
+    bool WCreate(const std::wstring &Name,uint Mode=FMF_UPDATE|FMF_SHAREREAD);
     virtual bool Close(); // 'virtual' for MultiFile class.
     bool Delete();
-    bool Rename(const wchar *NewName);
+    bool Rename(const std::wstring &NewName);
     bool Write(const void *Data,size_t Size);
     virtual int Read(void *Data,size_t Size);
     int DirectRead(void *Data,size_t Size);
@@ -107,11 +114,15 @@ class File
     void Flush();
     void SetOpenFileTime(RarTime *ftm,RarTime *ftc=NULL,RarTime *fta=NULL);
     void SetCloseFileTime(RarTime *ftm,RarTime *fta=NULL);
-    static void SetCloseFileTimeByName(const wchar *Name,RarTime *ftm,RarTime *fta);
-    void GetOpenFileTime(RarTime *ft);
+    static void SetCloseFileTimeByName(const std::wstring &Name,RarTime *ftm,RarTime *fta);
+#ifdef _UNIX
+    static void StatToRarTime(struct stat &st,RarTime *ftm,RarTime *ftc,RarTime *fta);
+#endif
+    void GetOpenFileTime(RarTime *ftm,RarTime *ftc=NULL,RarTime *fta=NULL);
     virtual bool IsOpened() {return hFile!=FILE_BAD_HANDLE;} // 'virtual' for MultiFile class.
-    int64 FileLength();
+    virtual int64 FileLength(); // 'virtual' for MultiFile class.
     void SetHandleType(FILE_HANDLETYPE Type) {HandleType=Type;}
+    void SetLineInputMode(bool Mode) {LineInput=Mode;}
     FILE_HANDLETYPE GetHandleType() {return HandleType;}
     bool IsSeekable() {return HandleType!=FILE_HANDLESTD;}
     bool IsDevice();
@@ -136,14 +147,9 @@ class File
 #endif
     static size_t CopyBufferSize()
     {
-#ifdef _WIN_ALL
-      // USB flash performance is poor with 64 KB buffer, 256+ KB resolved it.
-      // For copying from HDD to same HDD the best performance was with 256 KB
-      // buffer in XP and with 1 MB buffer in Win10.
-      return WinNT()==WNT_WXP ? 0x40000:0x100000;
-#else
-      return 0x100000;
-#endif
+      // Values in 0x100000 - 0x400000 range are ok, but multithreaded CRC32
+      // seems to benefit from 0x400000, especially on ARM CPUs.
+      return 0x400000;
     }
 };
 
