@@ -13,18 +13,18 @@
 #define   MBeta              L"beta"
 #define   Mx86               L"x86"
 #define   Mx64               L"x64"
-#define   MMonthJan          L"Jan"
-#define   MMonthFeb          L"Feb"
-#define   MMonthMar          L"Mar"
-#define   MMonthApr          L"Apr"
+#define   MMonthJan          L"January"
+#define   MMonthFeb          L"February"
+#define   MMonthMar          L"March"
+#define   MMonthApr          L"April"
 #define   MMonthMay          L"May"
-#define   MMonthJun          L"Jun"
-#define   MMonthJul          L"Jul"
-#define   MMonthAug          L"Aug"
-#define   MMonthSep          L"Sep"
-#define   MMonthOct          L"Oct"
-#define   MMonthNov          L"Nov"
-#define   MMonthDec          L"Dec"
+#define   MMonthJun          L"June"
+#define   MMonthJul          L"July"
+#define   MMonthAug          L"August"
+#define   MMonthSep          L"September"
+#define   MMonthOct          L"October"
+#define   MMonthNov          L"November"
+#define   MMonthDec          L"December"
 #define   MRARTitle1         L"\nUsage:     rar <command> -<switch 1> -<switch N> <archive> <files...>"
 #define   MUNRARTitle1       L"\nUsage:     unrar <command> -<switch 1> -<switch N> <archive> <files...>"
 #define   MRARTitle2         L"\n               <@listfiles...> <path_to_extract\\>"
@@ -122,15 +122,14 @@
 #define   MCHelpSwRI         L"\n  ri<P>[:<S>]   Set priority (0-default,1-min..15-max) and sleep time in ms"
 #define   MCHelpSwRR         L"\n  rr[N]         Add data recovery record"
 #define   MCHelpSwRV         L"\n  rv[N]         Create recovery volumes"
-#define   MCHelpSwS          L"\n  s[<N>,v[-],e] Create solid archive"
-#define   MCHelpSwSm         L"\n  s-            Disable solid archiving"
+#define   MCHelpSwS          L"\n  s[=<par>]     Create solid archive"
 #define   MCHelpSwSC         L"\n  sc<chr>[obj]  Specify the character set"
 #define   MCHelpSwSFX        L"\n  sfx[name]     Create SFX archive"
 #define   MCHelpSwSI         L"\n  si[name]      Read data from standard input (stdin)"
 #define   MCHelpSwSL         L"\n  sl<size>[u]   Process files with size less than specified"
 #define   MCHelpSwSM         L"\n  sm<size>[u]   Process files with size more than specified"
 #define   MCHelpSwT          L"\n  t             Test files after archiving"
-#define   MCHelpSwTK         L"\n  tk            Keep original archive time"
+#define   MCHelpSwTK         L"\n  tk[<date>]    Keep the original or set the specified archive time"
 #define   MCHelpSwTL         L"\n  tl            Set archive time to latest file"
 #define   MCHelpSwTN         L"\n  tn[mcao]<t>   Process files newer than <t> time"
 #define   MCHelpSwTO         L"\n  to[mcao]<t>   Process files older than <t> time"
